@@ -5,10 +5,9 @@ from typing import Any
 from urllib import parse, request
 
 from schemdule.helpers import buildMessage
-from schemdule.prompters import (Prompter, PrompterPayloadCollection,
-                                 PromptResult)
+from schemdule.prompters import PayloadCollection, Prompter, PromptResult
 
-__version__ = "0.0.8"
+__version__ = "0.0.9"
 
 
 class MiaotixingPrompter(Prompter):
@@ -18,7 +17,7 @@ class MiaotixingPrompter(Prompter):
         super().__init__(final)
         self.code = code
 
-    def prompt(self, payloads: PrompterPayloadCollection) -> PromptResult:
+    def prompt(self, payloads: PayloadCollection) -> PromptResult:
         with request.urlopen("http://miaotixing.com/trigger?" + parse.urlencode({"id": self.code, "text": buildMessage(payloads), "type": "json"})) as req:
             result = json.loads(req.read())
         if result["code"] == 0:
